@@ -7,7 +7,7 @@ from propelauth_py.api import _fetch_token_verification_metadata, TokenVerificat
     _fetch_org, _fetch_org_by_query, _fetch_users_by_query, _fetch_users_in_org, _create_user, _update_user_email, \
     _update_user_metadata, _create_magic_link, _migrate_user_from_external_source, _create_org, _add_user_to_org, \
     _delete_user, _disable_user, _enable_user, _allow_org_to_setup_saml_connection, \
-    _disallow_org_to_setup_saml_connection
+    _disallow_org_to_setup_saml_connection, _update_user_password
 from propelauth_py.auth_fns import wrap_validate_access_token_and_get_user, \
     wrap_validate_access_token_and_get_user_with_org, \
     wrap_validate_access_token_and_get_user_with_org_by_minimum_role, \
@@ -47,6 +47,7 @@ Auth = namedtuple("Auth", [
     "create_user",
     "update_user_email",
     "update_user_metadata",
+    "update_user_password",
     "create_magic_link",
     "migrate_user_from_external_source",
     "create_org",
@@ -97,8 +98,10 @@ def init_base_auth(auth_url: str, api_key: str, token_verification_metadata: Tok
         return _fetch_users_in_org(auth_url, api_key, org_id, page_size, page_number, include_orgs)
 
     def create_user(email, email_confirmed=False, send_email_to_confirm_email_address=True,
+                    ask_user_to_update_password_on_login=False,
                     password=None, username=None, first_name=None, last_name=None):
         return _create_user(auth_url, api_key, email, email_confirmed, send_email_to_confirm_email_address,
+                            ask_user_to_update_password_on_login,
                             password, username, first_name, last_name)
 
     def update_user_email(user_id, new_email, require_email_confirmation):
@@ -107,6 +110,9 @@ def init_base_auth(auth_url: str, api_key: str, token_verification_metadata: Tok
     def update_user_metadata(user_id, username=None, first_name=None, last_name=None):
         return _update_user_metadata(auth_url, api_key, user_id, username, first_name, last_name)
 
+    def update_user_password(user_id, password, ask_user_to_update_password_on_login=False):
+        return _update_user_password(auth_url, api_key, user_id, password, ask_user_to_update_password_on_login)
+
     def create_magic_link(email, redirect_to_url=None, expires_in_hours=None, create_new_user_if_one_doesnt_exist=None):
         return _create_magic_link(auth_url, api_key, email, redirect_to_url, expires_in_hours,
                                   create_new_user_if_one_doesnt_exist)
@@ -114,10 +120,12 @@ def init_base_auth(auth_url: str, api_key: str, token_verification_metadata: Tok
     def migrate_user_from_external_source(email, email_confirmed,
                                           existing_user_id=None, existing_password_hash=None,
                                           existing_mfa_base32_encoded_secret=None,
+                                          ask_user_to_update_password_on_login=False,
                                           enabled=None, first_name=None, last_name=None, username=None):
         return _migrate_user_from_external_source(auth_url, api_key, email, email_confirmed,
                                                   existing_user_id, existing_password_hash,
                                                   existing_mfa_base32_encoded_secret,
+                                                  ask_user_to_update_password_on_login,
                                                   enabled, first_name, last_name, username)
 
     def create_org(name):
@@ -190,6 +198,7 @@ def init_base_auth(auth_url: str, api_key: str, token_verification_metadata: Tok
         create_user=create_user,
         update_user_email=update_user_email,
         update_user_metadata=update_user_metadata,
+        update_user_password=update_user_password,
         create_magic_link=create_magic_link,
         migrate_user_from_external_source=migrate_user_from_external_source,
         create_org=create_org,
