@@ -7,6 +7,9 @@ class UpdateUserMetadataException(Exception):
     def __init__(self, field_to_errors):
         self.field_to_errors = field_to_errors
 
+class UpdateUserPasswordException(Exception):
+    def __init__(self, field_to_errors):
+        self.field_to_errors = field_to_errors
 
 class UpdateUserEmailException(Exception):
     def __init__(self, field_to_errors):
@@ -39,17 +42,6 @@ class UnauthorizedException(Exception):
         return UnauthorizedException("Invalid payload in token")
 
 
-class UnexpectedException(Exception):
-    def __init__(self, message):
-        self.message = message
-
-    @staticmethod
-    def invalid_minimum_required_role():
-        return UnexpectedException(
-            "minimum_required_role must be one of UserRole.Owner, UserRole.Admin, UserRole.Member, or None"
-        )
-
-
 class ForbiddenException(Exception):
     def __init__(self, message):
         self.message = message
@@ -63,5 +55,9 @@ class ForbiddenException(Exception):
         return ForbiddenException("User is not a member of org {}".format(org_id))
 
     @staticmethod
-    def user_less_than_minimum_role():
-        return ForbiddenException("User's role in org doesn't meet minimum required role")
+    def user_doesnt_have_required_role():
+        return ForbiddenException("User doesn't have required role")
+
+    @staticmethod
+    def user_doesnt_have_required_permission():
+        return ForbiddenException("User doesn't have required permission")
